@@ -106,7 +106,7 @@ class FiatAdapter(IImpactAdapter):
         self.config_base_path = config_base_path
         self.exe_path = exe_path
         self.delete_crashed_runs = delete_crashed_runs
-        self._model_root = str(model_root.resolve())
+        self._model_root = model_root.resolve().as_posix()
         self.fiat_columns = _FIAT_COLUMNS
         self.impact_columns = _IMPACT_COLUMNS  # columns of FA impact output
 
@@ -135,7 +135,7 @@ class FiatAdapter(IImpactAdapter):
     def read(self, path: Path) -> None:
         """Read the fiat model from the current model root."""
         if Path(self.model.root).resolve() != Path(path).resolve():
-            self.model.set_root(root=str(path), mode="r")
+            self.model.set_root(root=path.as_posix(), mode="r")
         self.model.read()
 
     def write(self, path_out: Union[str, os.PathLike], overwrite: bool = True) -> None:
@@ -148,7 +148,7 @@ class FiatAdapter(IImpactAdapter):
 
         write_mode = "w+" if overwrite else "w"
         with cd(path_out):
-            self.model.set_root(root=str(path_out), mode=write_mode)
+            self.model.set_root(root=path_out.as_posix(), mode=write_mode)
             self.model.write()
 
     def close_files(self):
@@ -205,7 +205,7 @@ class FiatAdapter(IImpactAdapter):
         self.close_files()
         if self.model_root.exists():
             logger.info(f"Deleting {self.model_root}")
-            shutil.rmtree(self.model_root)
+            shutil.rmtree(self.model_root, ignore_errors=True)
 
     def fiat_completed(self) -> bool:
         """Check if fiat has run as expected.
@@ -353,7 +353,7 @@ class FiatAdapter(IImpactAdapter):
                             os.remove(os.path.join(subdir, file))
 
                     if not os.listdir(subdir):
-                        os.rmdir(subdir)
+                        shutil.rmtree(subdir, ignore_errors=True)
 
             if strict:
                 raise RuntimeError(f"FIAT model failed to run in {path}.")
@@ -717,8 +717,8 @@ class FiatAdapter(IImpactAdapter):
         conversion_factor = wl_current_units.convert(self.model.exposure.unit)
 
         self.model.setup_hazard(
-            map_fn=map_fn,
-            map_type=map_type,
+            map_fn=[Path(p).as_posix() for p in map_fn],
+            map_type=map_type.value,
             rp=None,
             crs=None,  # change this in new version (maybe to str(floodmap.crs.split(':')[1]))
             nodata=-999,  # change this in new version
@@ -1160,7 +1160,7 @@ class FiatAdapter(IImpactAdapter):
                 object_dir=ObjectDir.measure,
                 obj_name=measure.name,
                 path=measure.polygon_file,
-            )
+            ).as_posix()
         else:
             polygon_file = None
 
@@ -1171,7 +1171,7 @@ class FiatAdapter(IImpactAdapter):
             non_building_names=self.config.non_building_names,
             aggregation=measure.aggregation_area_type,
             aggregation_area_name=measure.aggregation_area_name,
-            polygon_file=str(polygon_file),
+            polygon_file=polygon_file,
         )
 
         return ids
@@ -1365,6 +1365,11 @@ class FiatAdapter(IImpactAdapter):
             True,
             True,
         ]
+        metrics_new.loc["Show In Metrics Map", ["EW", "EWEAD", "EWCEAD"]] = [
+            False,
+            True,
+            False,
+        ]
         metrics_new.loc["Long Name", ["EW", "EWEAD", "EWCEAD"]] = [
             "Equity weight",
             "Equity weighted  expected annual damage",
@@ -1574,5 +1579,5 @@ class FiatAdapter(IImpactAdapter):
         )
         if simulation_path.exists():
             self.close_files()
-            shutil.rmtree(simulation_path)
+            shutil.rmtree(simulation_path, ignore_errors=True)
             logger.info(f"Deleted Delft-FIAT simulation folder: {simulation_path}")
