@@ -121,7 +121,7 @@ class SfincsAdapter(IHazardAdapter):
         self.settings = self.database.site.sfincs
         self.units = self.database.site.gui.units
         self._model = HydromtSfincsModel(
-            root=str(model_root.resolve()),
+            root=model_root.resolve().as_posix(),
             mode="r",
             logger=self._setup_sfincs_logger(model_root),
         )
@@ -130,7 +130,7 @@ class SfincsAdapter(IHazardAdapter):
     def read(self, path: Path):
         """Read the sfincs model from the current model root."""
         if Path(self._model.root).resolve() != Path(path).resolve():
-            self._model.set_root(root=str(path), mode="r")
+            self._model.set_root(root=path.as_posix(), mode="r")
         self._model.read()
 
     def write(self, path_out: Union[str, os.PathLike], overwrite: bool = True):
@@ -147,7 +147,7 @@ class SfincsAdapter(IHazardAdapter):
 
         write_mode = "w+" if overwrite else "w"
         with cd(path_out):
-            self._model.set_root(root=str(path_out), mode=write_mode)
+            self._model.set_root(root=path_out.as_posix(), mode=write_mode)
             self._model.write()
 
     def close_files(self):
@@ -190,10 +190,16 @@ class SfincsAdapter(IHazardAdapter):
             True if the model ran successfully, False otherwise.
 
         """
+        sfincs_bin = Settings().sfincs_bin_path
+        if not sfincs_bin or not sfincs_bin.exists():
+            raise FileNotFoundError(
+                f"SFINCS binary not found at {sfincs_bin}. Please check your settings."
+            )
+
         with cd(path):
             logger.info(f"Running SFINCS in {path}")
             process = subprocess.run(
-                str(Settings().sfincs_bin_path),
+                sfincs_bin.as_posix(),
                 stdout=subprocess.PIPE,
                 stderr=subprocess.PIPE,
                 text=True,
@@ -212,7 +218,7 @@ class SfincsAdapter(IHazardAdapter):
                             os.remove(os.path.join(subdir, file))
 
                     if not os.listdir(subdir):
-                        os.rmdir(subdir)
+                        shutil.rmtree(subdir, ignore_errors=True)
 
             if strict:
                 raise RuntimeError(f"SFINCS model failed to run in {path}.")
@@ -563,7 +569,7 @@ class SfincsAdapter(IHazardAdapter):
                 zsmax=floodmap_conversion * zsmax,
                 dep=dem_conversion * dem,
                 hmin=0.01,
-                floodmap_fn=str(floodmap_fn),
+                floodmap_fn=floodmap_fn.as_posix(),
             )
 
     def write_water_level_map(
@@ -803,7 +809,7 @@ class SfincsAdapter(IHazardAdapter):
                     zsmax=floodmap_conversion * zsmax,
                     dep=dem_conversion * dem,
                     hmin=0.01,
-                    floodmap_fn=str(floodmap_fn),
+                    floodmap_fn=floodmap_fn.as_posix(),
                 )
 
     ######################################
@@ -828,7 +834,7 @@ class SfincsAdapter(IHazardAdapter):
 
         if sim_path.parent.exists() and not any(sim_path.parent.iterdir()):
             # Remove the parent directory `simulations` if it is empty
-            sim_path.parent.rmdir()
+            shutil.rmtree(sim_path.parent, ignore_errors=True)
 
     def _run_risk_scenario(self, scenario: Scenario):
         """Run the whole workflow for a risk scenario.
@@ -1304,10 +1310,14 @@ class SfincsAdapter(IHazardAdapter):
             )
             return
 
-        logger.info(f"Setting discharge forcing for river: {discharge.river.name}")
-
-        time_frame = self.get_model_time()
         model_rivers = self._read_river_locations()
+        if model_rivers.empty:
+            logger.warning(
+                "Cannot add discharge forcing: No rivers defined in the sfincs model."
+            )
+            return
+        logger.info(f"Setting discharge forcing for river: {discharge.river.name}")
+        time_frame = self.get_model_time()
 
         # Check that the river is defined in the model and that the coordinates match
         river_loc = shapely.Point(
@@ -1626,7 +1636,7 @@ class SfincsAdapter(IHazardAdapter):
 
         # Initialize the tropical cyclone
         tc = TropicalCyclone()
-        tc.read_track(filename=str(track_forcing.path), fmt="ddb_cyc")
+        tc.read_track(filename=track_forcing.path.as_posix(), fmt="ddb_cyc")
 
         # Alter the track of the tc if necessary
         tc = self._translate_tc_track(
@@ -1705,17 +1715,22 @@ class SfincsAdapter(IHazardAdapter):
 
     def _read_river_locations(self) -> gpd.GeoDataFrame:
         path = self.get_model_root() / "sfincs.src"
-
-        with open(path) as f:
-            lines = f.readlines()
+        lines = []
+        if path.exists():
+            with open(path) as f:
+                lines = f.readlines()
         coords = [(float(line.split()[0]), float(line.split()[1])) for line in lines]
         points = [shapely.Point(coord) for coord in coords]
 
         return gpd.GeoDataFrame({"geometry": points}, crs=self._model.crs)
 
     def _read_waterlevel_boundary_locations(self) -> gpd.GeoDataFrame:
-        with open(self.get_model_root() / "sfincs.bnd") as f:
-            lines = f.readlines()
+        path = self.get_model_root() / "sfincs.bnd"
+        lines = []
+        if path.exists():
+            with open(path) as f:
+                lines = f.readlines()
+
         coords = [(float(line.split()[0]), float(line.split()[1])) for line in lines]
         points = [shapely.Point(coord) for coord in coords]
 
