@@ -1,5 +1,5 @@
 from pathlib import Path
-from typing import Any, List, Optional, Union
+from typing import Any, List, Literal, Optional, Union
 
 import geopandas as gpd
 import numpy as np
@@ -891,7 +891,7 @@ class FloodAdapt:
 
         output_path = self.database.get_flooding_path(scenario.name)
         obs_points["html"] = [
-            str(output_path.joinpath(f"{station}_timeseries.html"))
+            (output_path / f"{station}_timeseries.html").as_posix()
             for station in obs_points.name
         ]
 
@@ -935,42 +935,93 @@ class FloodAdapt:
 
         return infographic_path
 
-    def get_infometrics(self, name: str) -> pd.DataFrame:
-        """Return the metrics for the given scenario.
+    def get_infometrics(
+        self, name: str, aggr_name: Optional[str] = None
+    ) -> pd.DataFrame:
+        """Return the infometrics DataFrame for the given scenario and optional aggregation.
 
         Parameters
         ----------
         name : str
             The name of the scenario.
+        aggr_name : Optional[str], default None
+            The name of the aggregation, if any.
 
         Returns
         -------
-        metrics: pd.DataFrame
-            The metrics for the scenario.
+        df : pd.DataFrame
+            The infometrics DataFrame for the scenario (and aggregation if specified).
 
         Raises
         ------
         FileNotFoundError
-            If the metrics file does not exist.
+            If the metrics file does not exist for the given scenario (and aggregation).
         """
+        if aggr_name is not None:
+            fn = f"Infometrics_{name}_{aggr_name}.csv"
+        else:
+            fn = f"Infometrics_{name}.csv"
         # Create the infographic path
-        metrics_path = self.database.scenarios.output_path.joinpath(
-            name,
-            f"Infometrics_{name}.csv",
-        )
+        metrics_path = self.database.scenarios.output_path.joinpath(name, fn)
 
         # Check if the file exists
         if not metrics_path.exists():
             raise FileNotFoundError(
-                f"The metrics file for scenario {name}({str(metrics_path)}) does not exist."
+                f"The metrics file for scenario {name}({metrics_path.as_posix()}) does not exist."
             )
-
         # Read the metrics file
-        return MetricsFileReader(str(metrics_path)).read_metrics_from_file(
+        df = MetricsFileReader(metrics_path.as_posix()).read_metrics_from_file(
             include_long_names=True,
             include_description=True,
             include_metrics_table_selection=True,
+            include_metrics_map_selection=True,
         )
+        if aggr_name is not None:
+            df = df.T
+        return df
+
+    def get_aggr_metric_layers(
+        self,
+        name: str,
+        aggr_type: str,
+        type: Literal["single_event", "risk"] = "single_event",
+        rp: Optional[int] = None,
+        equity: bool = False,
+    ) -> list[dict]:
+        # Read infometrics from csv file
+        metrics_df = self.get_infometrics(name, aggr_name=aggr_type)
+
+        # Filter based on "Show in Metrics Map" column
+        if "Show In Metrics Map" in metrics_df.index:
+            mask = metrics_df.loc["Show In Metrics Map"].to_numpy().astype(bool)
+            metrics_df = metrics_df.loc[:, mask]
+
+        # Keep only relevant attributes of the infometrics
+        keep_rows = [
+            "Description",
+            "Long Name",
+            "Show In Metrics Table",
+            "Show In Metrics Map",
+        ]
+        metrics_df = metrics_df.loc[
+            [row for row in keep_rows if row in metrics_df.index]
+        ]
+
+        # Transform to list of dicts
+        metrics = []
+        for col in metrics_df.columns:
+            metric_dict = {"name": col}
+            # Add the first 4 rows as key-value pairs
+            for i, idx in enumerate(metrics_df.index):
+                metric_dict[idx] = metrics_df.loc[idx, col]
+            metrics.append(metric_dict)
+
+        # Get the filtered metrics layers from the GUI configuration
+        filtered_metrics = self.database.site.gui.output_layers.get_aggr_metrics_layers(
+            metrics, type, rp, equity
+        )
+
+        return filtered_metrics
 
     # Static
     def load_static_data(self):
